@@ -1,9 +1,9 @@
 .onLoad <- function(libname, pkgname) {
 
 	# default to print date-time stamp
-	options(filename.timestamp=2);
+	options(filenamer.timestamp=2);
 
 	# default to print date stamp for path
-	options(filename.path.timestamp=1);
+	options(filenamer.path.timestamp=1);
 
 }
